#! /usr/bin/env python
# -*- coding: utf-8 -*-

from distutils.core import setup

setup(name='python-mode.el',
      version='6.2.3',
      url='http://launchpad.net/python-mode',
      maintainer_email='andreas.roehler@online.de',
      maintainer='python-mode.el developers',
      description='Major mode for editing Python programs',
      download_url='http://launchpad.net/python-mode/trunk/6.2.3/+download/python-mode.el-6.2.3.tar.gz',
      license='GNU GPLv3, Python License',
      )
